==> lab_rat_wp_api-1.1.0.tar.gz: lib/src/domain/wc_product.dart <==
import 'wc_dimension.dart';
import 'wp_attribute.dart';
import 'wp_category.dart';
import 'wp_image.dart';
import 'package:lr_storage/lr_storage.dart';
import 'wp_tag.dart';

class WCProduct extends JsonObject {
  int id;
  int parentId;
  List<String> variations;

  String slug;
  String permalink;

  String name;
  String description;
  String short_description;

  String _dateCreated;
  String _dateModified;

  DateTime get dateCreated => DateTime.parse(_dateCreated);
  void set dateCreated(DateTime date) {
    _dateCreated = date.toString();
  }

  DateTime get dateModified => DateTime.parse(_dateModified);
  void set dateModified(DateTime date) {
    _dateModified = date.toString();
  }

  bool purchasable;

  String type;
  String status;
  bool featured;
  bool catalogVisibility;

  int price;
  int regular_price;
  int sale_price;
  bool on_sale;
  String price_html;

  List<int> crossSaleIds;
  List<int> upsaleIds;

  int weight;

  List<WPTag> tags;
  List<WPImage> images;
  List<WPCategory> categories;
  WCDimensions dimensions;
  List<WCAttribute> attributes;

  @override
  void fromJson(target) {
    id = target['id'];
    parentId = target['parent_id'];

    slug = target['slug'];
    permalink = target['permalink'];

    name = target['name'];
    description = target['description'];
    short_description = target['short_description'];

    dateCreated = target['date_created'];
    dateModified = target['date_modified'];

    purchasable = target['purchasable'];

    type = target['type'];
    status = target['status'];
    featured = target['featured'];
    catalogVisibility = target['catalog_visibility'];

    price = target['price'];
    regular_price = target['regular_price'];
    sale_price = target['sale_price'];
    on_sale = target['on_sale'];
    price_html = target['price_html'];

    crossSaleIds = target['cross_sale_ids'];
    upsaleIds = target['upsale_ids'];

    weight = target['weight'];

    tags = [];
    if (target.containsKey('tags'))
      tags = target['tags'].map((x) => new WPTag()..fromJson(x)).toList();

    images = [];
    if (target.containsKey('images'))
      images = target['images'].map((x) => new WPImage()..fromJson(x)).toList();

    categories = [];
    if (target.containsKey('categories'))
      categories = target['categories']
          .map((x) => new WPCategory()..fromJson(x))
          .toList();

    attributes = [];
    if (target.containsKey('attributes'))
      attributes = target['attributes']
          .map((x) => new WCAttribute()..fromJson(x))
          .toList();

    variations = [];
    if (target.containsKey('variations'))
      variations = target['variations']
          .map((x) => new WCProduct()..fromJson(x))
          .toList();

    dimensions = new WCDimensions()..fromJson(target['dimensions']);
  }
}

==> lab_rat_wp_api-1.1.13.tar.gz: lib/src/domain/wc_product.dart <==
import 'dart:convert';
import 'wc_dimension.dart';
import 'wp_attribute.dart';
import 'wp_category.dart';
import 'wp_image.dart';
import 'package:lr_storage/lr_storage.dart';
import 'wp_tag.dart';

class WCProduct extends JsonObject {
  int id;
  int parentId;
  List<String> variations;

  String slug;
  String permalink;

  String name;
  String description;
  String short_description;

  String _dateCreated;
  String _dateModified;

  DateTime get dateCreated => DateTime.parse(_dateCreated);
  void set dateCreated(DateTime date) {
    _dateCreated = date.toString();
  }

  DateTime get dateModified => DateTime.parse(_dateModified);
  void set dateModified(DateTime date) {
    _dateModified = date.toString();
  }

  bool purchasable;

  String type;
  String status;
  bool featured;
  bool catalogVisibility;

  int price;
  int regular_price;
  int sale_price;
  bool on_sale;
  String price_html;

  List<int> crossSaleIds;
  List<int> upsaleIds;

  int weight;

  List<WPTag> tags;
  List<WPImage> images;
  WPImage _image = null;
  WPImage get image =>
      _image != null ? _image : (images != null && images.length > 0) ? images.first : new WPImage.fromSrc('http://placehold.it/300/300');

  List<WPCategory> categories;
  WCDimensions dimensions;
  List<WCAttribute> attributes;

  @override
  void fromJson(target) {
    id = target['id'];
    parentId = target['parent_id'];

    slug = target['slug'];
    permalink = target['permalink'];

    name = target['name'];
    description = target['description'];
    short_description = target['short_description'];

    dateCreated = target['date_created'];
    dateModified = target['date_modified'];

    purchasable = target['purchasable'];

    type = target['type'];
    status = target['status'];
    featured = target['featured'];
    catalogVisibility = target['catalog_visibility'];

    price = target['price'];
    regular_price = target['regular_price'];
    sale_price = target['sale_price'];
    on_sale = target['on_sale'];
    price_html = target['price_html'];

    crossSaleIds = target['cross_sale_ids'];
    upsaleIds = target['upsale_ids'];

    weight = target['weight'];

    tags = [];
    if (target.containsKey('tags')) tags = target['tags'].map((x) => new WPTag()..fromJson(x)).toList();

    images = [];
    if (target.containsKey('images')) images = target['images'].map((x) => new WPImage()..fromJson(x)).toList();

    _image = null;
    if (target.containsKey('image')) {
      _image = new WPImage()..fromJson(target['image']);
    }
    categories = [];
    if (target.containsKey('categories')) categories = target['categories'].map((x) => new WPCategory()..fromJson(x)).toList();

    attributes = [];
    if (target.containsKey('attributes')) attributes = target['attributes'].map((x) => new WCAttribute()..fromJson(x)).toList();

    variations = [];
    if (target.containsKey('variations')) variations = target['variations'].toList();

    dimensions = new WCDimensions()..fromJson(target['dimensions']);
  }
}
